@@ -74,18 +74,10 @@ def update_text(token: SpanToken):
     """Update the text contents of a span token and its children.
     `InlineCode` tokens are left unchanged."""
     if isinstance(token, RawText) and args.type == "text":
-        print(
-    f"Replacing <{
-        args.find}> in <{
-            token.content}> to <{
-                args.replace}>")
+        print(f"Replacing <{args.find}> in <{token.content}> to <{args.replace}>")
         token.content = token.content.replace(args.find, args.replace)
     elif isinstance(token, Link) and args.type == "link":
-        print(
-    f"Replacing <{
-        args.find}> in <{
-            token.target}> to <{
-                args.replace}>")
+        print(f"Replacing <{args.find}> in <{token.target}> to <{args.replace}>")
         token.target = token.target.replace(args.find, args.replace)
 
     if not isinstance(token, InlineCode) and hasattr(token, "children"):
